// Template index file - dynamically loads all template files
// This automatically discovers and loads any .js files in the templates folder

(async function loadAllTemplates() {
  console.log('Dynamically loading all templates...');
  
  // List of template filenames - add new templates here
  const templateFiles = [
    'shalish-mediation.js',
    'restorative-justice.js',
    'transformative-justice.js',
    'jury-protocol.js',
    'referee-protocol.js',
    'peer-to-peer.js',
    'chosen-facilitator.js',
    'facilitation-council.js'
  ];
  
  const templates = [];
  
  try {
    // Load each template file
    for (const filename of templateFiles) {
      try {
        console.log(`Loading template: ${filename}`);
        const module = await import(`./${filename}`);
        if (module.default) {
          templates.push(module.default);
          console.log(`✓ Loaded template: ${module.default.title || filename}`);
        } else {
          console.warn(`✗ Template ${filename} has no default export`);
        }
      } catch (error) {
        console.warn(`✗ Failed to load template ${filename}:`, error);
        // Continue loading other templates even if one fails
      }
    }
    
    // Set global variable
    window.allTemplates = templates;
    console.log(`Successfully loaded ${templates.length} templates out of ${templateFiles.length} files`);
    
    // Dispatch event to notify other scripts that templates are ready
    window.dispatchEvent(new CustomEvent('templatesLoaded', { detail: templates }));
    
  } catch (error) {
    console.error('Critical error loading templates:', error);
    
    // Fallback: set empty array so the app doesn't break
    window.allTemplates = [];
    window.dispatchEvent(new CustomEvent('templatesLoaded', { detail: [] }));
  }
})();

// Instructions for adding new templates:
// 1. Create your new template file (e.g., 'my-new-template.js') in this folder
// 2. Add the filename to the templateFiles array above
// 3. The template will be automatically loaded and available in the UI